@@ -17,13 +17,15 @@
 
 #ifndef PUSB_HAL_H_
 # define PUSB_HAL_H_
+# include <dbus/dbus.h>
 
 DBusConnection *pusb_hal_dbus_connect(void);
 void pusb_hal_dbus_disconnect(DBusConnection *dbus);
-LibHalContext *pusb_hal_init(DBusConnection *dbus);
-void pusb_hal_destroy(LibHalContext *ctx);
-char *pusb_hal_get_property(LibHalContext *ctx, const char *udi, const char *name);
-int pusb_hal_check_property(LibHalContext *ctx, const char *udi, const char *name, const char *value);
-char *pusb_hal_find_item(LibHalContext *ctx, const char *property, const char *value, ...);
+char *pusb_hal_get_string_property(DBusConnection *dbus, const char *udi, const char *name);
+int pusb_hal_get_bool_property(DBusConnection *dbus, const char *udi, const char *name, dbus_bool_t *value);
+char **pusb_hal_get_string_array_property(DBusConnection *dbus, const char *udi, const char *name, int *n_items);
+int pusb_hal_check_property(DBusConnection *dbus, const char *udi, const char *name, const char *value);
+char *pusb_hal_find_item(DBusConnection *dbus, ...);
+void pusb_hal_free_string_array(char **str_array, int length);
 
 #endif /* !PUSB_HAL_H_ */
