@@ -18,6 +18,7 @@
 #include <libxml/xpath.h>
 #include <ctype.h>
 #include <string.h>
+#include "mem.h"
 #include "xpath.h"
 #include "log.h"
 
@@ -68,7 +69,10 @@ static int pusb_xpath_strip_string(char *dest, const char *src,
 		return (0);
 
 	if ((last_char - first_char) > (size - 1))
+	{
+		log_error("Device name is too long: %s", src);
 		return (0);
+	}
 
 	memset(dest, 0x0, size);
 	strncpy(dest, &(src[first_char]), last_char - first_char + 1);
@@ -123,17 +127,13 @@ int pusb_xpath_get_string_from(xmlDocPtr doc,
 	int		retval;
 
 	xpath_size = strlen(base) + strlen(path) + 1;
-	if (!(xpath = malloc(xpath_size)))
-	{
-		log_error("malloc error !\n");
-		return (0);
-	}
+	xpath = xmalloc(xpath_size);
 	memset(xpath, 0x00, xpath_size);
 	snprintf(xpath, xpath_size, "%s%s", base, path);
 	retval = pusb_xpath_get_string(doc, xpath, value, size);
 	if (retval)
 		log_debug("%s%s -> %s\n", base, path, value);
-	free(xpath);
+	xfree(xpath);
 	return (retval);
 }
 
@@ -170,15 +170,11 @@ int pusb_xpath_get_bool_from(xmlDocPtr doc,
 	int		retval;
 
 	xpath_size = strlen(base) + strlen(path) + 1;
-	if (!(xpath = malloc(xpath_size)))
-	{
-		log_error("malloc error!\n");
-		return (0);
-	}
+	xpath = xmalloc(xpath_size);
 	memset(xpath, 0x00, xpath_size);
 	snprintf(xpath, xpath_size, "%s%s", base, path);
 	retval = pusb_xpath_get_bool(doc, xpath, value);
-	free(xpath);
+	xfree(xpath);
 	return (retval);
 }
 
@@ -224,15 +220,11 @@ int pusb_xpath_get_time_from(xmlDocPtr doc,
 	int		retval;
 
 	xpath_size = strlen(base) + strlen(path) + 1;
-	if (!(xpath = malloc(xpath_size)))
-	{
-		log_error("malloc error!\n");
-		return (0);
-	}
+	xpath = xmalloc(xpath_size);
 	memset(xpath, 0x00, xpath_size);
 	snprintf(xpath, xpath_size, "%s%s", base, path);
 	retval = pusb_xpath_get_time(doc, xpath, value);
-	free(xpath);
+	xfree(xpath);
 	return (retval);
 }
 
@@ -256,14 +248,10 @@ int pusb_xpath_get_int_from(xmlDocPtr doc,
 	int		retval;
 
 	xpath_size = strlen(base) + strlen(path) + 1;
-	if (!(xpath = malloc(xpath_size)))
-	{
-		log_error("malloc error!\n");
-		return (0);
-	}
+	xpath = xmalloc(xpath_size);
 	memset(xpath, 0x00, xpath_size);
 	snprintf(xpath, xpath_size, "%s%s", base, path);
 	retval = pusb_xpath_get_int(doc, xpath, value);
-	free(xpath);
+	xfree(xpath);
 	return (retval);
 }
